Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(447)

Unified Diff: ui/views/bubble/bubble_frame_view.h

Issue 933893003: Use standard icon/title in global error bubble (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/views/global_error_bubble_view.cc ('k') | ui/views/bubble/bubble_frame_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/bubble/bubble_frame_view.h
diff --git a/ui/views/bubble/bubble_frame_view.h b/ui/views/bubble/bubble_frame_view.h
index 87fc1d78ca4d229a1fcd024c8e7eafd23bed3ae8..e86415d0b866b4ccc2f0fa0a7238260c92aa8c6e 100644
--- a/ui/views/bubble/bubble_frame_view.h
+++ b/ui/views/bubble/bubble_frame_view.h
@@ -21,6 +21,7 @@ namespace views {
class Label;
class LabelButton;
class BubbleBorder;
+class ImageView;
// The non-client frame view of bubble-styled widgets.
class VIEWS_EXPORT BubbleFrameView : public NonClientFrameView,
@@ -112,7 +113,8 @@ class VIEWS_EXPORT BubbleFrameView : public NonClientFrameView,
// Margins between the content and the inside of the border, in pixels.
gfx::Insets content_margins_;
- // The optional title and (x) close button.
+ // The optional title icon, title, and (x) close button.
+ views::ImageView* title_icon_;
Label* title_;
LabelButton* close_;
« no previous file with comments | « chrome/browser/ui/views/global_error_bubble_view.cc ('k') | ui/views/bubble/bubble_frame_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698